package org.nm.challenge.arrays;

/**
 * Interface for 2D Arrays.
 *
 */
public interface IArray2D {
	
	/**
	 * Copy the contents of the other 2D array
	 * into this 2D array.
	 * 
	 * @param other
	 */
	void copy(IArray2D other);
	
	/**
	 * Only call this method from the "owning" thread
	 * 
	 * @return the backing data -- remember the first index
	 * has ghost entries for index = 0 and index = size_y-1
	 * in the y direction (the first index).  The index = 0
	 * and index = 0 and index = size_x-1 are boundary data
	 * in the x direction (the second index)
	 */
	double[][] getData();
	
	/**
	 * @return the size in the x direction (the second index)
	 */
	int getSizeX();
	
	/**
	 * @return the size in the y direction (the first index).
	 * This may only refer to a window into the total array.
	 */
	int getSizeY();

	/**
	 * @return the total size in the y direction (the first index)
	 */
	int getTotalSizeY();
}
