package org.nm.challenge.arrays;

/**
 * @author rsqrd
 *
 * Not ThreadSafe
 */
public class SubArray2D implements IArray2D {

	private final double[][] data;
	private final int size_x;
	private final int size_y;
	private final int total_size_y;

	/**
	 * Create a 2D array that is a window into a (possibly) larger
	 * 2D array.  This SubArray2D is a slice in the y direction
	 * of the full array.  (The y direction is the first index,
	 * the x direction is the second index.)
	 * 
	 * @param parent - the (possibly larger) 2D array to window.
	 * @param size_y - the size of the y slice of the parent array
	 * @param offset_y - the offset of this window from the beginning of the
	 *                   parent array.
	 */
	public SubArray2D(IArray2D parent, int size_y, int offset_y) {
		this.size_x = parent.getSizeX();
		this.total_size_y = parent.getTotalSizeY();
		this.size_y = size_y;
		this.data = new double[size_y][];
		double[][] parentData = parent.getData();
		for (int i=0; i<size_y; ++i) {
			this.data[i] = parentData[i + offset_y];
		}
	}
	
	/* (non-Javadoc)
	 * @see org.nm.challenge.arrays.IArray2D#copy(org.nm.challenge.arrays.IArray2D)
	 */
	public void copy(IArray2D other) {
		double[][] otherData = other.getData();
		if (this.data.length != otherData.length) {
			throw new IllegalArgumentException("arrays not same size");
		}
		copy(otherData);
	}

	/* (non-Javadoc)
	 * @see org.nm.challenge.arrays.IArray2D#getData()
	 */
	public double[][] getData() {
		return data;
	}

	/**
	 * Copy otherData into this' data.
	 * 
	 * @param otherData
	 */
	private void copy(double[][] otherData) {
		for (int i = 0; i < this.data.length; ++i) {
			if (this.data[i].length != otherData[i].length) {
				throw new IllegalArgumentException("arrays not same size");
			}
			System.arraycopy(otherData[i], 0, this.data[i], 0, otherData[i].length);
		}
	}

	public int getSizeX() {
		return size_x;
	}

	public int getSizeY() {
		return size_y;
	}

	public int getTotalSizeY() {
		return total_size_y;
	}
}
