package org.nm.challenge.display;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Insets;
import java.awt.Point;
import java.awt.font.LineMetrics;
import java.awt.image.BufferedImage;
import java.awt.image.ColorModel;

import javax.swing.JComponent;

import org.nm.challenge.arrays.IArray2D;
import org.nm.challenge.display.colorramp.IColorRamp;
import org.nm.challenge.display.colorramp.RainbowColorRamp;

public class Display2DComponent extends JComponent implements IDisplay {

	private static final long serialVersionUID = 1L;
	private IArray2D mass = null;
	private final IColorRamp colorRamp = new RainbowColorRamp();
	private BufferedImage bi = null;
	private int oldHeight = 0;
	private int oldWidth = 0;
	private String title = "";

	public Display2DComponent() {
		super();
		setMinimumSize(new Dimension(100, 200));
		setPreferredSize(new Dimension(250, 500));
		setMaximumSize(new Dimension(1000, 2000));
	}

	@Override
	public void paint(Graphics g) {
		Graphics2D g2 = (Graphics2D) g;
		//paintCircles(g2);
		paintImage(g2);
		//super.paint(g);
	}

	@Override
	public void update(Graphics g) {
		//super.update(g);
		paint(g);
	}
	
	public void update(final int iteration, final IArray2D mass) {
		setTitle("iteration: " + iteration);
		setData(mass);
		repaint();
	}

	protected void setTitle(String string) {
		title = string;
	}

	private Point calcDataLocation(int x, int y, int dataWidth, int dataHeight,
			int width, int height) {
		double px = x * ((double)dataWidth)/((double)width);
		double py = y * ((double)dataHeight)/((double)height);
		return new Point((int)px, (int)py);
	}

	private int getColor(double datum, ColorModel colorModel) {
		int[] colors = colorRamp.getColor(datum/10.0);
		int color;
		try {
			color = colorModel.getDataElement(colors, 0);
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			color = 0;
		}
		return color;
	}

	private void paintImage(Graphics2D g2) {
		//System.out.println("in paintImage");
		//Insets insets = getInsets();
		Insets insets = new Insets(0,0,0,0);

		int width = getSize().width - insets.left - insets.right;
		int height = getSize().height - insets.bottom - insets.top;
		if (bi == null || oldWidth != width || oldHeight != height) {
			bi = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
			oldWidth = width;
			oldHeight = height;
		}
		if (mass == null) {
			return;
		}
		ColorModel colorModel = bi.getColorModel();
		double[][] dmass = mass.getData();
		int dataWidth = dmass.length;
		int dataHeight = dmass[0].length;
		for (int i=0; i < width; ++i) {
			for (int j=0; j < height; ++j) {
				Point dataLocation = calcDataLocation(i, j, dataHeight, dataWidth,
						width, height);
				int y = dataLocation.x;
				int x = dataLocation.y;
				double datum = dmass[x][y];
				int color = getColor(datum, colorModel);
				bi.setRGB(i, j, color);
			}
		}
		g2.drawImage(bi, insets.left, insets.top, this);
		g2.setColor(Color.WHITE);
		LineMetrics lineMetrics = g2.getFont().getLineMetrics(title, g2.getFontRenderContext());
		int textHeight = (int) lineMetrics.getHeight();
		g2.drawString(title, 10, textHeight);
	}

	private void setData(IArray2D mass) {
		this.mass = mass;
	}
	
}
