package org.nm.challenge.display.colorramp;

public class CalculatedRainbowColorRamp implements IColorRamp {

	public int[] getColor(int val) {
		return getColor((double) val / 256.0);
	}

	public int[] getColor(double val) {
		float[] fcolors = getColor(val, 0, 1.0);
		int[] icolors = new int[]{(int)(255*fcolors[0]), (int)(255*fcolors[1]),
			(int)(255*fcolors[2])};
		return icolors;
	}

	/*
	   Return a RGB colour value given a scalar v in the range [vmin,vmax]
	   In this case each colour component ranges from 0 (no contribution) to
	   1 (fully saturated), modifications for other ranges is trivial.
	   The colour is clipped at the end of the scales if v is outside
	   the range [vmin,vmax]
	   typedef struct {
	      double r,g,b;
	   } COLOUR;
	*/
	private float[] getColor(double v, double vmin, double vmax)
	{
	   float[] c = {1.0f,1.0f,1.0f}; // white
	   double dv;

	   if (v < vmin)
	      v = vmin;
	   if (v > vmax)
	      v = vmax;
	   dv = vmax - vmin;

	   if (v < (vmin + 0.25 * dv)) {
	      c[0] = 0;
	      c[1] = (float) (4 * (v - vmin) / dv);
	   } else if (v < (vmin + 0.5 * dv)) {
	      c[0] = 0;
	      c[2] = (float) (1 + 4 * (vmin + 0.25 * dv - v) / dv);
	   } else if (v < (vmin + 0.75 * dv)) {
	      c[0] = (float) (4 * (v - vmin - 0.5 * dv) / dv);
	      c[2] = 0;
	   } else {
	      c[1] = (float) (1 + 4 * (vmin + 0.75 * dv - v) / dv);
	      c[2] = 0;
	   }

	   return(c);
	}

}
