#!/bin/sh
set -v

# Each user should run this and carefully follow the instructions
# to setup their own development environment

# This sets up the parallel Eclipse development environment. It
# installs the main eclipse SDK, the C development environment,
# the parallel tools and the parallel language development 
# tools

SRC_DIR=${HOME}/Desktop
if test `uname` == "Darwin"; then
  ECLIPSE_FILE=eclipse-SDK-3.2.2-macosx-carbon.tar.gz
  CDT_FILE=org.eclipse.cdt-3.1.2-macosx.ppc.tar.gz
else
  ECLIPSE_FILE=eclipse-SDK-3.2.2-linux-gtk.tar.gz
  CDT_FILE=org.eclipse.cdt-3.1.2-linux.x86.tar.gz
fi

PTP_FILE=org.eclipse.ptp-1.1.1.tar.gz
PTP_PLDT_FILE=org.eclipse.ptp.pldt-1.1.1.tar.gz

# Some environment variables are needed to get the 
# path to the java executable and the LD_LIBRARY_PATH
# to get the BUILD script to work.

# Edit the .bashrc file and add the following near the top
# vi ~/.bashrc

# export PATH=/usr/local/jdk1.6.0_02/bin:$PATH (not needed on Mac)
# export PATH=/usr/local/bin:$PATH (on Mac only)
# export PATH/${HOME}/eclipse:$PATH
# export LD_LIBRARY_PATH=/usr/local/lib

# Now source your .bashrc file 
#    source ~/.bashrc

if test -d eclipse; then
  echo "ERROR: Eclipse directory already exists"
  exit
fi

tar -xzf ${SRC_DIR}/${ECLIPSE_FILE}
tar -xzf ${SRC_DIR}/${CDT_FILE}
tar -xzf ${SRC_DIR}/${PTP_FILE}
tar -xzf ${SRC_DIR}/${PTP_PLDT_FILE}
if test `uname` == "Darwin"; then
  cd eclipse/plugins/org.eclipse.ptp.macosx.x86_1.1.0
else
  cd eclipse/plugins/org.eclipse.ptp.linux.x86_1.1.0
fi
sh BUILD

# Now manually start up eclipse
# -- type eclipse or eclipse/eclipse from your home directory
# -- click on workspace

# Select Window --> Preferences at the bottom (Top bar Eclipse on Mac)
# Click on PTP and Parallel Language Development to open menus
# Select MPI and add /usr/local/include to include path

# Select Open RTE and see that Proxy servers are setup
# Select Simulation and set 2 cpus on machine

# Return to main eclipse screen

# Back to main eclipse screen

# Import Java and C Projects
# 1) File -> Import ...
# 2) General -> Existing Projects into Workspace
# 3) select "Select Archive file:" radio button
# 4) Browse to the JavaWave.zip file (four projects should be shown and checked)
# 5) chose Finish

# May need to go to Window->Preferences->Java->Compiler and change compliance
# level for the Java compiler from 1.4 to 5.0

# Add New Project by Clicking on File -->New --> Project
# Select Managed Make C Project
# Type in name of Project --> Wave
# Click OK until MPI Project Settings screen comes up
# Select "Add MPI project settings to this project

# Now right click on Project name in C/C++ Projects window on the left
# Near the bottom select Properties
# Select C/C++ Build
# Select GCC C Linker/Libraries
# Add two libraries
#    mpe
#    X11

# Back to main eclipse screen

# Right click on Wave project and select import
# Select General --> File System 
#  Get the four files from the CWave directory
#      wave.c, wave.h, display.c, memory.c

# If build of project has problems
# Now right click (ctrl click on Mac) on Project name in C/C++ Projects window on the left
# Near the bottom select Properties
# Select C/C++ Build
# Select GCC C Linker/Libraries
# Add two libraries
#    mpe
#    X11
# Need /usr/X11R6/lib added on Mac

# Turn on line numbers in editor
# Right click on left margin of file in editing window or 
# Select Window --> General --> Editor --> Text Editor
# Click on box for line numbers

# Setup run objects
# Click on Run on Top menu bar and Select run way down on menu
# Select Java Application. Click on rectangle with plus (new) to setup new run object
#   Name -- JavaWave in Wave
# Select Java Application. Click on rectangle with plus (new) to setup new run object
#   Name -- JavaWaveThreaded in WaveThreaded
# Select C/C++ Local Application. Click on rectangle with plus (new) to setup new run object
#   Name -- CWave, Executable release/CWave
# Select Parallel Application. Click on rectangle with plus. 
#   Name -- Parallel Flow, Executable release/CWave, num processors 2
# On Mac, open up an xterm and type "xhost +" to allow the MPE in the CWave code to open 
# an X display window

# Select PTP Runtime perspective or the PTP debug perspective for running or
# debugging your parallel program

# When running a parallel program and get "Debug UI" error, switch perspectives
# from C++ to PTP runtime to get rid of the error. Pull down Window, select 
# perspective, other, and select PTP runtime.
